@@ -1,9 +1,3 @@
-#include	<stdio.h>
-#include	<string.h>
-#include	<netinet/in.h>
-#include	<sys/ipc.h>
-#include	<sys/msg.h>
-#include	<mqueue.h>
 #include	"dsgwd_pi.h"
 #include	"node.h"
 
