@@ -23,7 +23,10 @@ void	config(int argc, char **argv)
 		config_file = fopen (argv[1], "r");
 		if (!config_file)
 		{
-			printf ("config file not found (%s)\n", argv[1]);
+			logfile = fopen (LOGFILE, "a");
+			now = time(NULL);
+			fprintf (logfile, "%24.24s config file not found (%s)\n", ctime(&now), argv[1]);
+			fclose (logfile);
 			exit (1);
 		}
 	} 
@@ -32,7 +35,10 @@ void	config(int argc, char **argv)
 		config_file = fopen ("/etc/dsgwd_pi.conf","r");
 		if (!config_file)
 		{
-			printf ("config file not found (/etc/dsgwd_pi.conf)\n");
+			logfile = fopen (LOGFILE, "a");
+			now = time(NULL);
+			fprintf (logfile, "%24.24s config file not found (/etc/dsgwd_pi.conf)\n", ctime(&now));
+			fclose (logfile);
 			exit (1);
 		}
 	}
