@@ -18,13 +18,13 @@
 	2014.02.05 V00.12 Added log file
 	2014.02.06 V00.13 Bug fixed
 	2014.02.06 V00.14 Added KeepAlive for TCP
+	2014.02.07 V00.15 Changed hole punching interval
 */
 
 #include "dsgwd_pi.h"
 #include "version.h"
 #include "node.h"
 
-void	exit (int status);
 void	*node_adapter (void *arg);
 void	send_dsvt(void);
 void	receive_dsvt(void);
@@ -494,11 +494,7 @@ int main(int argc, const char **argv)
 				if (ConnectWait)
 				{
 					AckTimeOut++;
-					if (AckTimeOut == 20)	/* 100 m sec, */
-					{
-						ConSend();
-					}
-					if (AckTimeOut > 40)	/* 200 m sec. */
+					if (AckTimeOut > 100)	/* 500 m sec. */
 					{
 						RelaySW = TRUE;
 						ConnectWait = FALSE;
@@ -510,6 +506,11 @@ int main(int argc, const char **argv)
 						fprintf (logfile, "%24.24s Change to Relay Mode\n", ctime(&now));
 						fclose (logfile);
 					}
+                                        else if ((AckTimeOut % 20) == 0)     /* 100 m sec, interval */
+                                        {
+                                                ConSend();
+                                        }
+
 				}
 				if (DVwait)
 				{
